@@ -1,6 +1,6 @@
 =head1 NAME
 
-StreamFinder - Fetch actual raw streamable URLs from various radio-station websites.
+StreamFinder - Fetch actual raw streamable URLs from various radio-station and video websites.
 
 =head1 INSTALLATION
 
@@ -94,7 +94,7 @@ StreamFinder accepts a valid radio station URL on supported websites and
 returns the actual stream URL(s), title, and cover art icon for that station.  
 The purpose is that one needs one of these URLs 
 in order to have the option to stream the station/video in one's own choice of 
-audio player software rather than using their web browser and accepting any / 
+media player software rather than using their web browser and accepting any / 
 all flash, ads, javascript, cookies, trackers, web-bugs, and other crapware 
 associated with that method of playing.  The author uses his own custom 
 all-purpose media player called "fauxdacious" (his custom hacked version of 
@@ -109,7 +109,10 @@ object actually refers to a specific video, but functions the same way!
 
 Each site is supported by a separate subpackage (StreamFinder::I<Package>), 
 which is determined and selected based on the url when the StreamFinder object 
-is created.  The methods are overloaded by the selected subpackage's methods.
+is created.  The methods are overloaded by the selected subpackage's methods.  
+
+Please see the POD. documentation for each subpackage for important additional 
+information on options and features specific to each site / subpackage!
 
 One or more playable streams can be returned for each station / video.  
 
@@ -143,11 +146,11 @@ Returns an array of strings representing all stream urls found.
 Similar to B<get>() except it only returns a single stream representing 
 the first valid stream found.  
 
-Current options are:  I<-random> and I<-noplaylists>.  By default, the 
-first ("best"?) stream is returned.  If I<-random> is specified, then 
+Current options are:  I<"random"> and I<"noplaylists">.  By default, the 
+first ("best"?) stream is returned.  If I<"random"> is specified, then 
 a random one is selected from the list of streams found.  
-If I<-noplaylists> is specified, and the stream to be returned is a 
-"playlist" (.pls extension), it is first fetched and the first entry 
+If I<"noplaylists"> is specified, and the stream to be returned is a 
+"playlist" (.pls or .m3u? extension), it is first fetched and the first entry 
 in the playlist is returned.  This is needed by Fauxdacious Mediaplayer.
 
 =item $station->B<count>()
@@ -190,6 +193,13 @@ Returns a two-element array consisting of the extension (ie. "png",
 NOTE:  If no "banner image" (usually a larger image) is found, 
 the "icon image" data will be returned.
 
+=item $video->B<getType>()
+
+Returns the station's type (I<submodule-name>).  
+(one of:  "BannedVideo", "Facebook", "IHeartRadio", "RadioNet", 
+"Radionomy", "Reciva", "Tunein", or "Youtube" - depending on 
+the sight that matched the URL.
+
 =back
 
 =head1 CONFIGURATION FILES
@@ -327,7 +337,7 @@ use strict;
 use warnings;
 use vars qw(@ISA @EXPORT $VERSION);
 
-our $VERSION = '1.12';
+our $VERSION = '1.13';
 our $DEBUG = 1;
 
 require Exporter;
