@@ -22,8 +22,7 @@ file.
 
 	use StreamFinder::BannedVideo;
 
-	my $video = new StreamFinder::BannedVideo(<url>,
-			'secure_shoutcast', 'secure', 'any', '!rtmp');
+	my $video = new StreamFinder::BannedVideo(<url>);
 
 	die "Invalid URL or no streams found!\n"  unless ($video);
 
@@ -79,12 +78,12 @@ file.
 
 =head1 DESCRIPTION
 
-StreamFinder::BannedVideo accepts a valid video URL on Banned.Video 
+StreamFinder::BannedVideo accepts a valid video ID or URL on Banned.Video 
 (Alex Jone's infowars new video site after communist YouTube BANNED his videos) 
 and, at the moment, youtube-dl doesn't convert them (yet?);
-and returns the actual stream URL(s) and cover art icon for that video.  
+and returns the actual title, stream URL(s) and cover art icon for that video.  
 The purpose is that one needs one of these URLs in order to have the option to 
-stream the video in one's own choice of audio player software rather than 
+stream the video in one's own choice of media player software rather than 
 using their web browser and accepting any / all flash, ads, javascript, 
 cookies, trackers, web-bugs, censorship, and other crapware that can come with 
 that method of playing.  The author uses his own custom all-purpose media 
@@ -98,18 +97,20 @@ One or more stream URLs can be returned for each video.
 
 =over 4
 
-=item B<new>(I<url> [, I<-keep> => "type1[,type2...]"|I<[> type1[,type2...] I<]> | , I<-debug> [ => 0|1|2 ] ])
+=item B<new>(I<url> [, I<-keep> => "type1,type2?..." | [type1,type2?...] ] | [, I<-debug> [ => 0|1|2 ] ])
 
-Accepts an Banned.Video ID or URL and creates and returns a new video object, or 
+Accepts a Banned.Video ID or URL and creates and returns a new video object, or 
 I<undef> if the URL is not a valid Banned.Video video or no streams are found.
 
 The optional I<keep> can be either a comma-separated string or an array reference 
 ([...]) of stream types to keep (include) and returned in order specified 
 (type1, type2...).  Each "type" can be one of:  extension (ie. m4a, mp4, etc.), 
-"direct", "stream", or ("any" or "all").  The default list is:  'm4a,direct,stream',
-meaning that all m4a streams followed by all "direct" streams ("directUrl" in page, 
-followed by all remaining (non-direct "streamUrl") streams.  More 
-than one value can be specified to control order of search.   
+"direct", "stream", or ("any" or "all").
+
+DEFAULT keep list is:  'm4a,direct,stream', meaning that all m4a streams followed 
+by all "direct" streams ("directUrl" in page, followed by all remaining 
+(non-direct "streamUrl") streams.  More than one value can be specified to 
+control order of search.
 
 =item $video->B<get>()
 
@@ -120,10 +121,10 @@ Returns an array of strings representing all stream urls found.
 Similar to B<get>() except it only returns a single stream representing 
 the first valid stream found.  
 
-Current options are:  I<-random> and I<-noplaylists>.  By default, the 
-first ("best"?) stream is returned.  If I<-random> is specified, then 
+Current options are:  I<"random"> and I<"noplaylists">.  By default, the 
+first ("best"?) stream is returned.  If I<"random"> is specified, then 
 a random one is selected from the list of streams found.  
-If I<-noplaylists> is specified, and the stream to be returned is a 
+If I<"noplaylists"> is specified, and the stream to be returned is a 
 "playlist" (.pls or .m3u? extension), it is first fetched and the first entry 
 in the playlist is returned.  This is needed by Fauxdacious Mediaplayer.
 
@@ -159,7 +160,7 @@ Returns a two-element array consisting of the extension (ie. "png",
 
 =item $video->B<getType>()
 
-Returns the stream's type ("BannedVideo").
+Returns the video's type ("BannedVideo").
 
 =back
 
