@@ -42,24 +42,6 @@ file.
 
 	print "Video ID=$videoID\n";
 	
-	my $icon_url = $video->getIconURL();
-
-	if ($icon_url) {   #SAVE THE ICON TO A TEMP. FILE:
-
-		my ($image_ext, $icon_image) = $video->getIconData();
-
-		if ($icon_image && open IMGOUT, ">/tmp/${videoID}.$image_ext") {
-
-			binmode IMGOUT;
-
-			print IMGOUT $icon_image;
-
-			close IMGOUT;
-
-		}
-
-	}
-
 	my $stream_count = $video->count();
 
 	print "--Stream count=$stream_count=\n";
@@ -75,14 +57,15 @@ file.
 =head1 DESCRIPTION
 
 StreamFinder::Facebook accepts a valid Facebook video URL and
-returns the actual stream URL for that video.  The purpose is that one needs 
-this URL in order to have the option to stream the video in one's own choice 
-of audio player software rather than using their web browser and accepting 
-any / all flash, ads, javascript, cookies, trackers, web-bugs, and other 
-crapware that can come with that method of playing.  The author uses his own 
-custom all-purpose media player called "fauxdacious" (his custom hacked 
-version of the open-source "audacious" audio player).  "fauxdacious" can 
-incorporate this module to decode and play Facebook.com videos.
+returns the actual stream URL and title for that video.  The purpose is that 
+one needs this URL in order to have the option to stream the video in one's 
+own choice of media player software rather than on Facebook using their web 
+browser and accepting any / all flash, ads, javascript, cookies, trackers, 
+web-bugs, and other crapware that can come with that method of playing.  
+The author uses his own custom all-purpose media player called "fauxdacious" 
+(his custom hacked version of the open-source "audacious" audio player).  
+"fauxdacious" can incorporate this module to decode and play 
+Facebook.com videos.
 
 NOTE:  You must create the config file: ~/.config/StreamFinder/Facebook/config 
 containing the two lines:  
@@ -129,23 +112,31 @@ Returns the video's title (description).
 
 Returns the url for the video's "cover art" icon image, if any.
 
+NOTE:  Not currently applicable to Facebook videos.
+
 =item $video->B<getIconData>()
 
 Returns a two-element array consisting of the extension (ie. "png", 
 "gif", "jpeg", etc. and the actual icon image (binary data), if any.
 
+NOTE:  Not currently applicable to Facebook videos.
+
 =item $video->B<getImageURL>()
 
 Returns the url for the video's "cover art" banner image.
 
+NOTE:  Not currently applicable to Facebook videos.
+
 =item $video->B<getImageData>()
 
 Returns a two-element array consisting of the extension (ie. "png", 
 "gif", "jpeg", etc. and the actual video's banner image (binary data).
 
+NOTE:  Not currently applicable to Facebook videos.
+
 =item $video->B<getType>()
 
-Returns the stream's type ("Facebook").
+Returns the video's type ("Facebook").
 
 =back
 
