@@ -22,8 +22,8 @@ file.
 
 	use StreamFinder::IHeartRadio;
 
-	my $station = new StreamFinder::IHeartRadio(<url>,
-			'secure_shoutcast', 'secure', 'any', '!rtmp');
+	my $station = new StreamFinder::IHeartRadio(<url>, -keep => 
+			{'secure_shoutcast', 'secure', 'any'}, -skip => 'rtmp');
 
 	die "Invalid URL or no streams found!\n"  unless ($station);
 
@@ -79,10 +79,10 @@ file.
 
 =head1 DESCRIPTION
 
-StreamFinder::IHeartRadio accepts a valid radio station URL on IHeartRadio.com 
-and returns the actual stream URL(s) and cover art icon for that station.  
+StreamFinder::IHeartRadio accepts a valid radio station or podcast ID or URL on 
+IHeartRadio.com and returns the actual stream URL(s), title, and cover art icon.  
 The purpose is that one needs one of these URLs in order to have the option to 
-stream the station in one's own choice of audio player software rather than 
+stream the station in one's own choice of media player software rather than 
 using their web browser and accepting any / all flash, ads, javascript, 
 cookies, trackers, web-bugs, and other crapware that can come with that method 
 of playing.  The author uses his own custom all-purpose media player called 
@@ -105,7 +105,9 @@ I<-keep> and I<-skip> specify a list of one or more I<streamtypes> to either
 include or skip respectively.  The list for each can be either a comma-separated 
 string or an array reference ([...]) of stream types, in the order they should be 
 returned.  Each stream type in the list can be one of:  any, secure, secure_pls, 
-pls, secure_hls, hls, secure_shortcast, shortcast, secure_rtmp, rtmp, etc.  
+pls, secure_hls, hls, secure_shortcast, shortcast, secure_rtmp, rtmp, (I<ext>, 
+ie. mp4) etc.  
+
 NOTE:  This is now the preferred method over the DEPRECIATED one below.  If using 
 this method, do NOT include the inverter ("!") in front of the stream types, as 
 this is not used - these should be put in the I<-skip> list now.  The method 
@@ -113,17 +115,15 @@ below will be REMOVED in a later version soon!
 
 DEPRECIATED:  use The optional I<streamtype> can be one of:  any, secure, 
 secure_pls, pls, secure_hls, hls, secure_shortcast, shortcast, secure_rtmp, 
-rtmp, etc.  More than one value can be specified to control order of search.  
-A I<streamtype> can be preceeded by an exclamantion point ("!") to reject that 
-type of stream.  If "any" appears in the list, it should be the last specifier 
-without a "!" preceeding it, and itself should not be preceeded with a "!" 
-(inverter)!  
-
-For example, the list:  'secure_shoutcast', 'secure', 'any', '!rtmp' 
-would try to find a "secure_shoutcast" (https) shortcast stream, if none found, 
-would then look for any secure (https) stream, failing that, would look for 
-any valid stream.  All the while skipping any that are "rtmp" 
-streams.
+rtmp etc.  More than one value can be specified to control 
+order of search.  A I<streamtype> can be preceeded by an exclamantion point 
+("!") to reject that type of stream.  If "any" appears in the list, it should 
+be the last specifier without a "!" preceeding it, and itself should not be 
+preceeded with a "!" (inverter)!  For example, the list:  'secure_shoutcast', 
+'secure', 'any', '!rtmp' would try to find a "secure_shoutcast" (https) 
+shortcast stream, if none found, would then look for any secure (https) 
+stream, failing that, would look for any valid stream.  All the while 
+skipping any that are "rtmp" streams.
 
 =item $station->B<get>()
 
@@ -134,10 +134,10 @@ Returns an array of strings representing all stream urls found.
 Similar to B<get>() except it only returns a single stream representing 
 the first valid stream found.  
 
-Current options are:  I<-random> and I<-noplaylists>.  By default, the 
-first ("best"?) stream is returned.  If I<-random> is specified, then 
+Current options are:  I<"random"> and I<"noplaylists">.  By default, the 
+first ("best"?) stream is returned.  If I<"random"> is specified, then 
 a random one is selected from the list of streams found.  
-If I<-noplaylists> is specified, and the stream to be returned is a 
+If I<"noplaylists"> is specified, and the stream to be returned is a 
 "playlist" (.pls or .m3u? extension), it is first fetched and the first entry 
 in the playlist is returned.  This is needed by Fauxdacious Mediaplayer.
 
@@ -174,7 +174,7 @@ Returns a two-element array consisting of the extension (ie. "png",
 
 =item $station->B<getType>()
 
-Returns the stream's type ("IHeartRadio").
+Returns the station's type ("IHeartRadio").
 
 =back
 
@@ -392,11 +392,13 @@ sub new
 	if ($url =~ /^https?\:/) {
 		$self->{'id'} = $1  if ($url2fetch =~ m#\/([^\/]+)\/?$#);
 	} else {
-		$self->{'id'} = $url;
-		$url2fetch = 'https://www.iheart.com/live/' . $url;
+		my ($id, $podcastid) = split(m#\/#, $url2fetch);
+		$self->{'id'} = $id;
+		$url2fetch = ($podcastid ? 'https://www.iheart.com/podcast/' : 'https://www.iheart.com/live/') . $id;
+		$url2fetch .= '/episode/' . $podcastid  if ($podcastid);
 	}
 	my $html = '';
-	print STDERR "-0(IHeartRadio): URL=$url2fetch=\n"  if ($DEBUG);
+	print STDERR "-1 FETCHING URL=$url2fetch=\n"  if ($DEBUG);
 	my $ua = LWP::UserAgent->new(@userAgentOps);		
 	$ua->timeout($uops{'timeout'});
 	$ua->cookie_jar({});
@@ -408,7 +410,7 @@ sub new
 		print STDERR $response->status_line  if ($DEBUG);
 	}
 	print STDERR "-1: html=$html=\n"  if ($DEBUG > 1);
-	return undef  unless ($html);  #STEP 1 FAILED, INVALID STATION URL, PUNT!
+	return undef  unless ($html && $self->{'id'});  #STEP 1 FAILED, INVALID STATION URL, PUNT!
 
 	my $html2 = '';
 	my $streamhtml0 = ($html =~ /\"streams\"\s*\:\s*\{([^\}]+)\}/) ? $1 : '';
@@ -423,7 +425,7 @@ sub new
 		my $id = $url;
 		$id =~ s#\/$##;
 		$id = $1  if ($id =~ m#([^\/]+)$#);
-		$self->{'id'} = $id;
+		$self->{'id'} .= '/' . $id  if ($id);
 		$self->{'title'} = ($html =~ s#\<title[^\>]+\>([^\<]+)\<\/title\>##s) ? $1 : '';
 		$self->{'description'} = ($html =~ m#\"podcastDescription\"\>(?:\<[^\>]+\>)?([^\<]+)#s) ? $1 : $self->{'title'};
 		$self->{'description'} = HTML::Entities::decode_entities($self->{'description'});
