@@ -75,30 +75,30 @@ file.
 =head1 DESCRIPTION
 
 StreamFinder::Reciva accepts a valid radio station ID or URL on 
-radios.reciva.com and returns the actual streamurl and cover art icon 
-for that station.  The purpose is that one needs one of these URLs 
+radios.reciva.com and returns the actual stream URL(s), title, and cover 
+art icon for that station.  The purpose is that one needs one of these URLs 
 in order to have the option to stream the station in one's own choice of 
-audio player software rather than using their web browser and accepting any / 
+media player software rather than using their web browser and accepting any / 
 all flash, ads, javascript, cookies, trackers, web-bugs, and other crapware 
 that can come with that method of playing.  The author uses his own custom 
 all-purpose media player called "fauxdacious" (his custom hacked version of 
 the open-source "audacious" audio player.  "fauxdacious" incorporates this 
 module to decode and play reciva.com streams.
 
-StreamFinder::Reciva accepts a valid radio station URL on radios.reciva.com and 
-returns the actual stream URL(s) and cover art icon for that station.  
-The purpose is that one needs one of these URLs in order to have the option to 
-stream the station in one's own choice of audio player software rather than 
-using their web browser and accepting any / all flash, ads, javascript, 
-cookies, trackers, web-bugs, and other crapware that can come with that method 
-of playing.  The author uses his own custom all-purpose audio player called 
-"fauxdacious" (his custom hacked version of the open-source "audacious" 
-media player).  "fauxdacious" can incorporate this module to decode and play 
-reciva.com streams.
+StreamFinder::Reciva accepts a valid radio station IDF / URL on 
+radios.reciva.com and returns the actual stream URL(s) and cover art icon 
+for that station.  The purpose is that one needs one of these URLs in order 
+to have the option to stream the station in one's own choice of audio player 
+software rather than using their web browser and accepting any / all flash, 
+ads, javascript, cookies, trackers, web-bugs, and other crapware that can 
+come with that method of playing.  The author uses his own custom 
+all-purpose audio player called "fauxdacious" (his custom hacked version of 
+the open-source "audacious" media player).  "fauxdacious" can incorporate 
+this module to decode and play reciva.com streams.
 
 One or more streams can be returned for each station.
 
-NOTE:  This sight STILL uses the ancient SSL TLSv1, which LWP::UserAgent 
+NOTE:  reciva.com STILL uses the ancient SSL TLSv1, which LWP::UserAgent 
 no longer plays nice with without coaxing!  Therefore, if you don't have 
 the fallback B<wget> installed, ie. M$-Windows users, etc. you will need to 
 create a simple text config file named "~/.config/StreamFinder/Reciva/config 
@@ -132,11 +132,11 @@ Returns an array of strings representing all stream urls found.
 Similar to B<get>() except it only returns a single stream representing 
 the first valid stream found.  
 
-Current options are:  I<-random> and I<-noplaylists>.  By default, the 
-first ("best"?) stream is returned.  If I<-random> is specified, then 
+Current options are:  I<"random"> and I<"noplaylists">.  By default, the 
+first ("best"?) stream is returned.  If I<"random"> is specified, then 
 a random one is selected from the list of streams found.  
-If I<-noplaylists> is specified, and the stream to be returned is a 
-"playlist" (.pls extension), it is first fetched and the first entry 
+If I<"noplaylists"> is specified, and the stream to be returned is a 
+"playlist" (.pls or .m3u? extension), it is first fetched and the first entry 
 in the playlist is returned.  This is needed by Fauxdacious Mediaplayer.
 
 =item $station->B<count>()
@@ -171,7 +171,7 @@ Returns a two-element array consisting of the extension (ie. "png",
 
 =item $station->B<getType>()
 
-Returns the stream's type ("Reciva").
+Returns the station's type ("Reciva").
 
 =back
 
@@ -192,6 +192,12 @@ and the options are loaded into a hash used only by the specific
 I<-debug> => [0|1|2], and most of the L<LWP::UserAgent> options.  
 Blank lines and lines starting with a "#" sign are ignored.
 
+Among options valid for Reciva streams is the *.reciva.com - specific 
+SSL options currently needed to access their servers described in 
+the B<new()> function:
+
+'reciva_ssl_opts' => {verify_hostname => 0, SSL_version => 'TLSv1'}
+
 Options specified here override any specified in I<~/.config/StreamFinder/config>.
 
 =item ~/.config/StreamFinder/config
