@@ -76,10 +76,10 @@ file.
 
 =head1 DESCRIPTION
 
-StreamFinder::Tunein accepts a valid radio station URL on Tunein.com and
-returns the actual stream URL(s) and cover art icon for that station.  
+StreamFinder::Tunein accepts a valid radio station or podcast ID or URL on 
+Tunein.com and returns the actual stream URL(s), title, and cover art icon.  
 The purpose is that one needs one of these URLs in order to have the option to 
-stream the station in one's own choice of audio player software rather than 
+stream the station in one's own choice of media player software rather than 
 using their web browser and accepting any / all flash, ads, javascript, 
 cookies, trackers, web-bugs, and other crapware that can come with that method 
 of playing.  The author uses his own custom all-purpose media player called 
@@ -111,10 +111,10 @@ Returns an array of strings representing all stream urls found.
 Similar to B<get>() except it only returns a single stream representing 
 the first valid stream found.  
 
-Current options are:  I<-random> and I<-noplaylists>.  By default, the 
-first ("best"?) stream is returned.  If I<-random> is specified, then 
+Current options are:  I<"random"> and I<"noplaylists">.  By default, the 
+first ("best"?) stream is returned.  If I<"random"> is specified, then 
 a random one is selected from the list of streams found.  
-If I<-noplaylists> is specified, and the stream to be returned is a 
+If I<"noplaylists"> is specified, and the stream to be returned is a 
 "playlist" (.pls or .m3u? extension), it is first fetched and the first entry 
 in the playlist is returned.  This is needed by Fauxdacious Mediaplayer.
 
@@ -151,7 +151,7 @@ Returns a two-element array consisting of the extension (ie. "png",
 
 =item $station->B<getType>()
 
-Returns the stream's type ("Tunein").
+Returns the station's type ("Tunein").
 
 =back
 
@@ -279,6 +279,9 @@ EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 =cut
 
+my $haveYoutube = 0;
+eval "use StreamFinder::Youtube; \$haveYoutube = 1; 1";
+
 package StreamFinder::Tunein;
 
 use strict;
@@ -288,6 +291,7 @@ use HTML::Entities ();
 use LWP::UserAgent ();
 use vars qw(@ISA @EXPORT);
 
+
 my $DEBUG = 0;
 my %uops = ();
 my @userAgentOps = ();
@@ -353,6 +357,7 @@ sub new
 		$url2fetch .= '/?topicId=' . $podcastid  if ($podcastid);
 		$self->{'id'} = $id;
 	}
+	print STDERR "-1 FETCHING URL=$url2fetch=\n"  if ($DEBUG);
 	my $response = $ua->get($url2fetch);
 	if ($response->is_success) {
 		$html = $response->decoded_content;
@@ -420,14 +425,16 @@ sub new
 		my $tryStream = "http://opml.radiotime.com/Tune.ashx?id=$stationID";
 		$self->{'streams'} = [$tryStream];
 		$self->{'cnt'} = 1;
-		my $tryYoutubeDL = new StreamFinder::Youtube($tryStream, -debug => $DEBUG, -notitle => 1);
-		if ($tryYoutubeDL) {
-			my $firstStream = $tryYoutubeDL->getURL();
-			print STDERR "i:Found stream ($firstStream) via youtube-dl.\n"  if ($DEBUG);
-			$self->{'title'} ||= $tryYoutubeDL->getTitle();
-			$self->{'iconurl'} ||= $tryYoutubeDL->getIconUrl();
-			unshift @{$self->{'streams'}}, $firstStream;
-			$self->{'cnt'}++;
+		if ($haveYoutube) {
+			my $tryYoutubeDL = new StreamFinder::Youtube($tryStream, -debug => $DEBUG, -notitle => 1);
+			if ($tryYoutubeDL) {
+				my $firstStream = $tryYoutubeDL->getURL();
+				print STDERR "i:Found stream ($firstStream) via youtube-dl.\n"  if ($DEBUG);
+				$self->{'title'} ||= $tryYoutubeDL->getTitle();
+				$self->{'iconurl'} ||= $tryYoutubeDL->getIconUrl();
+				unshift @{$self->{'streams'}}, $firstStream;
+				$self->{'cnt'}++;
+			}
 		}
 	}
 	$self->{'total'} = $self->{'cnt'};
