@@ -75,8 +75,8 @@ file.
 =head1 DESCRIPTION
 
 StreamFinder::Youtube accepts a valid full Youtube video ID or URL on 
-youtube, brighteon, vimeo, et. al. that the "youtube-dl" program can handle, 
-and returns the actual stream URL, title and cover art icon for that video.  
+youtube, brighteon, vimeo, et. al. that the "youtube-dl" program supports, 
+and returns the actual stream URL, title, and cover art icon for that video.  
 The purpose is that one needs this URL in order to have the option to 
 stream the video in one's own choice of media player software rather 
 than using their web browser and accepting any / all flash, ads, 
@@ -115,10 +115,10 @@ Returns an array of strings representing all stream urls found.
 Similar to B<get>() except it only returns a single stream representing 
 the first valid stream found.  
 
-Current options are:  I<-random> and I<-noplaylists>.  By default, the 
-first ("best"?) stream is returned.  If I<-random> is specified, then 
+Current options are:  I<"random"> and I<"noplaylists">.  By default, the 
+first ("best"?) stream is returned.  If I<"random"> is specified, then 
 a random one is selected from the list of streams found.  
-If I<-noplaylists> is specified, and the stream to be returned is a 
+If I<"noplaylists"> is specified, and the stream to be returned is a 
 "playlist" (.pls or .m3u? extension), it is first fetched and the first entry 
 in the playlist is returned.  This is needed by Fauxdacious Mediaplayer.
 
@@ -154,7 +154,7 @@ Returns a two-element array consisting of the extension (ie. "png",
 
 =item $video->B<getType>()
 
-Returns the stream's type ("Youtube").
+Returns the video's type ("Youtube").
 
 =back
 
